@@ -4,7 +4,7 @@ use 5.010;
 use Moose;
 
 # ABSTRACT: Manage your datebase schema via checksums
-our $VERSION = '1.100';
+our $VERSION = '1.101';
 
 use DBI;
 use Digest::SHA1;
@@ -296,7 +296,7 @@ DBIx::SchemaChecksum - Manage your datebase schema via checksums
 
 =head1 VERSION
 
-version 1.100
+version 1.101
 
 =head1 SYNOPSIS
 
@@ -325,7 +325,7 @@ different database versions.
 
 B<Caveat:> C<DBIx::SchemaChecksum> only works with database engines
 that support changes to the schema inside a transaction. We know this
-works wit PostgreSQL and SQLite. We know it does not work with MySQL
+works with PostgreSQL and SQLite. We know it does not work with MySQL
 and Oracle. We don't know how other database engines behave, but would
 be happy to hear about your experiences.
 
@@ -337,7 +337,11 @@ interface to make working with your schema a breeze.
 
 =head2 EXAMPLE WORKFLOW
 
-So have this genious idea for a new startup that will make you incredibly rich and famous. Usually such ideas involve a database. So you grab your L<favourite database engine|http://postgresql.org/> and start a new database:
+So have this genious idea for a new startup that will make you incredibly rich and famous. 
+
+=head3 Collect underpants
+
+Usually such ideas involve a database. So you grab your L<favourite database engine|http://postgresql.org/> and start a new database:
 
   ~/Gnomes$ createdb gnomes    # createdb is a postgres tool
 
@@ -444,6 +448,8 @@ Yay, this looks much better!
 
 Now you can finally start to collect underpants!
 
+=head3 Teamwork
+
 Some weeks later (you have now convinced a friend to join you in your quest for fortune) a C<git pull> drops a new file into your C<sql> directory. It seems that your colleague needs some teaks to the database:
 
   ~/Gnomes$ cat sql/underpants_need_washing.sql
@@ -490,7 +496,9 @@ And it magically works:
   ~/Gnomes$ dbchecksum apply_changes
   db checksum 094ef4321e60b50c1d34529c312ecc2fcbbdfb51 matching sql/underpants_need_washing.sql
 
-Profit!
+=head3 Profit!
+
+This section is left empty as an exercise for the reader!
 
 =head2 TIPS & TRICKS
 
